@@ -108,10 +108,14 @@
         stop("msfit cannot (yet) compute the result for a weighted model")
     Terms <- terms(object)
     strat <- attr(Terms, "specials")$strata
+    if (is.null(strat)) stop("object has to have strata() term")
     cluster <- attr(Terms, "specials")$cluster
     if (length(cluster)) stop("cluster terms are not supported")
     if (!is.null(attr(object$terms, "specials")$tt))
       stop("msfit cannot yet process coxph models with a tt term")
+    
+    # Not pretty, but avoids x=TRUE issues
+    if (!is.null(object[['x']])) object[['x']] <- NULL
 
     resp <-  attr(Terms, "variables")[attr(Terms, "response")]
     nvar <- length(object$coefficients)
@@ -186,8 +190,11 @@
       sf0 <- summary(survfit(object))
       norisk <- sf0$n.risk
       noevent <- sf0$n.event
+      
+      # Allows two-state models (same fix as when vartype = "aalen")
+      trans.new <- if (is.null(sf0$strata)) 1L else as.numeric(sf0$strata)
       sf0 <- data.frame(time=sf0$time,Haz=-log(sf0$surv),norisk=norisk,
-                        noevent=noevent, trans=as.numeric(sf0$strata))
+                        noevent=noevent, trans=trans.new)
       allt <- sort(unique(c(sf0$time,lasty)))
       nt <- length(allt)
       K <- nrow(to.trans2(trans))
@@ -248,10 +255,12 @@
       if (length(labels)==1) {
         if (labels == "strata(trans)") { # no covariates, no call to C
           sf0 <- summary(survfit(object))
+          trans.new <- if (is.null(sf0$strata)) 1L else as.numeric(sf0$strata)
           norisk <- sf0$n.risk
           noevent <- sf0$n.event
           sf0 <- data.frame(time=sf0$time,Haz=-log(sf0$surv),norisk=norisk,
-                            noevent=noevent,var=sf0$std.err^2/(sf0$surv)^2,trans=as.numeric(sf0$strata))
+                            noevent=noevent,var=sf0$std.err^2/(sf0$surv)^2,
+                            trans=trans.new)
           allt <- sort(unique(c(sf0$time,lasty)))
           nt <- length(allt)
           K <- max(sf0$trans)
@@ -408,7 +417,7 @@
         varHaz <- as.vector(t(matrix(surv$varHaz,ncol=nt))) # change row and column order
         
         hlp <- matrix(c(rep(1:n2,rep(n2,n2)),rep(1:n2,n2)),n2^2,2)
-        hlp <- hlp[hlp[,1]<=hlp[,2],]
+        hlp <- hlp[hlp[,1]<=hlp[,2], , drop=FALSE]
         varHaz <- data.frame(time=rep(untimes,n2*(n2+1)/2),varHaz=varHaz,
                              trans1=rep(hlp[,1],rep(nt,n2*(n2+1)/2)),
                              trans2=rep(hlp[,2],rep(nt,n2*(n2+1)/2)))
