@@ -148,11 +148,16 @@ plot.probtrans <- function(x,
   
   # Prelims
   type <- match.arg(type)
-  if (!inherits(x, "probtrans"))
-    stop("'x' must be a 'probtrans' object")
+  if (!inherits(x, "probtrans")) stop("'x' must be a 'probtrans' object")
   
   # Ggplot version
   if (use.ggplot) {
+    
+    # Check for ggplot2
+    if (!requireNamespace("ggplot2", quietly = TRUE)) {
+      stop("Package ggplot2 needed for this function to work. Please install it.", call. = FALSE)
+    }
+    
     conf.type <- match.arg(conf.type)
     
     p <- ggplot.probtrans(
